/**
 * Copyright (C) 2012-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtable.client.components;

import static com.google.gwt.query.client.GQuery.$;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.dussan.vaadin.dtable.client.VDTable;
import org.dussan.vaadin.dtable.client.components.base.TableComponent;

import com.google.gwt.query.client.GQuery;

public class Order
    extends TableComponent
{

    private String mainId = "div#v-dtable";

    private List<String> orders = new ArrayList<>();

    public Order( VDTable dTable )
    {
        super( dTable );
    }

    private int getOrderColumn( String order )
    {
        return Integer.parseInt( order.split( " " )[0] );
    }

    private String getOrderType( String order )
    {
        return order.split( " " )[1];
    }

    private void setOrders( Object[] orders )
    {
        if ( orders != null && 0 < orders.length )
        {
            this.orders.clear();
            if ( !"none".equals( orders[0] ) )
            {
                for ( Object order : orders )
                {
                    order = order.toString()
                                 .toLowerCase();
                    int column = getOrderColumn( order.toString() );
                    if ( getDTable().isFrozen( column ) && getDTable().config()
                                                                      .isOrderedFrozenTableEnabled() )
                    {
                        this.orders.add( order.toString() );
                    }
                    else if ( !getDTable().isFrozen( column ) && getDTable().config()
                                                                            .isOrderedTableEnabled() )
                    {
                        this.orders.add( order.toString() );
                    }
                }
            }
        }
    }

    public boolean isOrderEnabled( int column )
    {
        return 1 < getDTable().getAllRows() && ( !getDTable().isFrozen( column ) ? getDTable().config()
                                                                                              .isOrderedTableEnabled()
                        : getDTable().config()
                                     .isOrderedFrozenTableEnabled() );
    }

    public int getSize( boolean isTableFrozen )
    {
        if ( orders.isEmpty() )
        {
            return 0;
        }
        else
        {
            int columnsCounter = 0;
            for ( int col = 0; col < orders.size(); col++ )
            {
                int column = getOrderColumn( orders.get( col ) );
                if ( isTableFrozen && getDTable().isFrozen( column ) )
                {
                    columnsCounter += 1;
                }
                else if ( !isTableFrozen && !getDTable().isFrozen( column ) )
                {
                    columnsCounter += 1;
                }
            }
            return columnsCounter;
        }
    }

    public String getOrders()
    {
        StringBuilder builder = new StringBuilder();
        for ( String order : orders )
        {
            builder.append( order.toUpperCase() )
                   .append( "_:_" );
        }
        return builder.length() == 0 ? "none" : builder.substring( 0, builder.length() - 3 );
    }

    public void setOrder( GQuery td, String order )
    {
        if ( td != null && !td.isEmpty() )
        {
            int columnId = Integer.parseInt( td.id()
                                               .split( ":" )[2] );
            if ( order == null )
            {
                for ( int col = orders.size() - 1; 0 <= col; col-- )
                {
                    int column = getOrderColumn( orders.get( col ) );
                    if ( getDTable().isFrozen( columnId ) && getDTable().isFrozen( column ) )
                    {
                        orders.remove( col );
                    }
                    else if ( !getDTable().isFrozen( columnId ) && !getDTable().isFrozen( column ) )
                    {
                        orders.remove( col );
                    }
                }
            }
            else
            {
                String tempOrder = order.toLowerCase();
                int column = -1;
                for ( int col = 0; col < orders.size(); col++ )
                {
                    if ( getOrderColumn( orders.get( col ) ) == columnId )
                    {
                        column = col;
                    }
                }

                if ( "asc".equals( tempOrder ) || "desc".equals( tempOrder ) )
                {
                    if ( 0 <= column )
                    {
                        orders.set( column, columnId + " " + tempOrder );
                    }
                    else
                    {
                        orders.add( columnId + " " + tempOrder );
                    }
                }
                else if ( "remove".equals( tempOrder ) && 0 <= column )
                {
                    orders.remove( column );
                }
            }
        }
    }

    @Override
    public void setIds()
    {
        if ( !mainId.endsWith( Long.toString( getDTable().getId() ) ) )
        {
            mainId += Long.toString( getDTable().getId() );
        }
    }

    public void processData( Map<String, String> data )
    {
        if ( data.containsKey( "order" ) )
        {
            setOrders( VDTable.toStringArray( data.get( "order" ) ) );
        }
        else
        {
            unload();
        }
    }

    @Override
    public void load()
    {
        setIds();
        setEventsHandlerEnabled();
    }

    @Override
    public void unload()
    {
        setEventsHandlerDisabled();
    }

    public void apply()
    {
        if ( ( getDTable().config()
                          .isOrderedFrozenTableEnabled()
            || getDTable().config()
                          .isOrderedTableEnabled() )
            && this.orders != null && !this.orders.isEmpty() )
        {
            String tdId = "td [id='" + getDTable().getId() + "h:0:_']";
            for ( String order : this.orders )
            {
                int column = getOrderColumn( order );
                if ( ( getDTable().config()
                                  .isOrderedFrozenTableEnabled()
                    && getDTable().isFrozen( column ) )
                    || ( getDTable().config()
                                    .isOrderedTableEnabled()
                        && !getDTable().isFrozen( column ) ) )
                {
                    GQuery td = $( tdId.replace( "_", Integer.toString( column ) ) );
                    $( td ).removeClass( "asc", "desc" )
                           .addClass( getOrderType( order ) );
                }
            }
        }
        else
        {
            unload();
        }
    }

    @Override
    public void setEventsHandlerEnabled()
    {
        // not used
    }

    @Override
    public void setEventsHandlerDisabled()
    {
        // not used
    }
}
