/**
 * Copyright (C) 2012-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtable.client.components.events;

import static com.google.gwt.query.client.GQuery.$;

import org.dussan.vaadin.dtable.client.components.Splitter;

import com.google.gwt.dom.client.Style.Cursor;
import com.google.gwt.query.client.GQuery;
import com.google.gwt.query.client.css.CSS;
import com.google.gwt.query.client.css.Length;
import com.google.gwt.query.client.css.TakesCssValue.CssSetter;
import com.google.gwt.user.client.Event;

public class SplitterEvent
{

    private SplitterEvent()
    {
        // Auto-generated constructor stub
    }
    
    private static void showFrozenTable( Splitter splitter, boolean show )
    {
        splitter.getDTable()
                .hideFrozenTable( !show );
        splitter.getDTable()
                .checkContainerDimensionsAndTableCellAlignments( $( splitter.getFrozenBodyId() ),
                                                                 $( splitter.getBodyId() ) );
    }

    private static void click( Splitter splitter )
    {
        GQuery mainContainerWrapper = $( splitter.getMainId() ).find( splitter.getMainContainerId() );
        GQuery splitterContainer = $( splitter.getMainId() ).find( splitter.getSplitterContainerId() );
        CssSetter left = CSS.LEFT.with( Length.px( 0 ) );
        CssSetter top = CSS.TOP.with( Length.px( 0 ) );
        CssSetter width = CSS.WIDTH.with( Length.px( mainContainerWrapper.width() + splitter.getDTable()
                                                                                            .getBrowserOffset() ) );
        CssSetter height = CSS.HEIGHT.with( Length.px( mainContainerWrapper.height() + splitter.getDTable()
                                                                                               .getBrowserOffset() ) );
        CssSetter sLeft = CSS.LEFT.with( Length.px( splitter.getSplitterLeft() ) );
        CssSetter sTop = top;
        CssSetter sWidth = CSS.WIDTH.with( Length.px( splitterContainer.width() ) );
        CssSetter sHeight = CSS.HEIGHT.with( Length.px( splitterContainer.height() ) );

        mainContainerWrapper.append( $( "<div/>" ).id( "dt-splitter-background" )
                                                  .html( "&nbsp;" )
                                                  .css( CSS.CURSOR.with( Cursor.COL_RESIZE ) )
                                                  .css( left )
                                                  .css( top )
                                                  .css( width )
                                                  .css( height ) )
                            .append( $( "<div/>" ).id( "dt-splitter" )
                                                  .html( "&nbsp;" )
                                                  .css( sLeft )
                                                  .css( sTop )
                                                  .css( sWidth )
                                                  .css( sHeight ) );
    }

    private static void resizeFrozenTable( Splitter splitter, int x )
    {
        GQuery splitterContainer = $( splitter.getMainId() ).find( splitter.getSplitterContainerId() );
        splitter.setMouseX( x );
        splitter.setSplitterLeft( splitterContainer.position().left - splitter.getDTable()
                                                                              .getBrowserOffset() );
        click( splitter );
        splitter.activateMoveEventHandler( true );
    }

    public static boolean mousedown( Splitter splitter, Event event )
    {
        if ( splitter.getSplitterContainerId()
                     .equals( "td#" + $( event ).id() ) )
        {
            if ( $( splitter.getFrozenBodyId() ).parent()
                                                .parent()
                                                .width() == 0 )
            {
                showFrozenTable( splitter, true );
                return false;
            }
            else if ( splitter.getDTable()
                              .config()
                              .isResizeFrozenTableEnabled() )
            {
                resizeFrozenTable( splitter, event.getClientX() );
                return false;
            }
            else if ( splitter.getDTable()
                              .config()
                              .isHideFrozenTableEnabled() )
            {
                showFrozenTable( splitter, false );
                return false;
            }
        }
        return true;
    }

    public static void mousemove( Splitter splitter, String id, int x )
    {
        int containerWidth = $( splitter.getMainId() ).find( splitter.getMainContainerWrapperId() )
                                                      .width()
            - splitter.getDTable()
                      .config()
                      .getTableMinimalWidth();

        if ( splitter.getSplitterBackgroundId()
                     .equals( "div#" + id ) )
        {
            int left = splitter.getSplitterLeft() + x - splitter.getMouseX();
            int right = Math.min( left, containerWidth );
            left = Math.max( splitter.getDTable()
                                     .config()
                                     .getTableFrozenMinimalWidth(),
                             right );
            $( splitter.getSplitterId() ).css( CSS.LEFT.with( Length.px( left ) ) );
        }
    }

    public static void mouseup( Splitter splitter, String id, int x )
    {
        int containerWidth = $( splitter.getMainId() ).find( splitter.getMainContainerWrapperId() )
                                                      .width()
            - splitter.getDTable()
                      .config()
                      .getTableMinimalWidth();

        if ( splitter.getSplitterBackgroundId()
                     .equals( "div#" + id ) )
        {
            mouseout( splitter, id );

            GQuery mainContainerWrapper = $( splitter.getMainId() ).find( splitter.getMainContainerWrapperId() );
            if ( splitter.getDTable()
                         .config()
                         .isHideFrozenTableEnabled()
                && x == splitter.getMouseX() )
            {
                splitter.getDTable()
                        .hideFrozenTable( true );
            }
            else
            {
                int left = splitter.getSplitterLeft() + x - splitter.getMouseX();
                int right = Math.min( left, containerWidth );
                left = Math.max( splitter.getDTable()
                                         .config()
                                         .getTableFrozenMinimalWidth(),
                                 right );
                mainContainerWrapper.children( "table" )
                                    .children( "tr" )
                                    .children( splitter.getFilter()[0] )
                                    .css( CSS.WIDTH.with( Length.px( left ) ) );
                mainContainerWrapper.children( "table" )
                                    .children( "tr" )
                                    .children( "td" )
                                    .children( splitter.getFilter()[1] )
                                    .css( CSS.WIDTH.with( Length.px( left ) ) );

                splitter.getDTable()
                        .hideFrozenTable( false );
                splitter.getDTable()
                        .setFrozenTableWidth( left );
                if ( splitter.getDTable()
                             .config()
                             .isFrozenTableEnabled() )
                {
                    splitter.getDTable()
                            .setFrozenTableWidth( Math.max( splitter.getDTable()
                                                                    .config()
                                                                    .getTableFrozenMinimalWidth(),
                                                            splitter.getDTable()
                                                                    .getFrozenTableWidth() ) );
                    splitter.getDTable()
                            .showFrozenTable( true );
                }
                else
                {
                    splitter.getDTable()
                            .setFrozenTableWidth( 0 );
                    splitter.getDTable()
                            .showFrozenTable( false );
                }
            }
            // set width to 100% - Chrome want this
            mainContainerWrapper.children( "tr" )
                                .children( "td" )
                                .children( splitter.getFilter()[1] )
                                .css( CSS.WIDTH.with( Length.pct( 100 ) ) );

            splitter.getDTable()
                    .checkContainerDimensionsAndTableCellAlignments( $( splitter.getFrozenBodyId() ),
                                                                     $( splitter.getBodyId() ) );
        }
    }

    public static void mouseout( Splitter splitter, String id )
    {
        if ( splitter.getSplitterBackgroundId()
                     .equals( "div#" + id ) )
        {
            $( splitter.getMainId() ).find( splitter.getSplitterBackgroundId() )
                                     .remove();
            $( splitter.getMainId() ).find( splitter.getSplitterId() )
                                     .remove();
            splitter.activateMoveEventHandler( false );
        }
    }

}
