/**
 * Copyright (C) 2012-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtable.client.connector;

import org.dussan.vaadin.dtable.DTable;
import org.dussan.vaadin.dtable.client.VDTable;
import org.dussan.vaadin.dtable.client.events.TableEvents;
import org.dussan.vaadin.dtable.client.rpc.DTableServerRpc;
import org.dussan.vaadin.dtable.client.state.TableState;

import com.google.gwt.event.logical.shared.ValueChangeEvent;
import com.google.gwt.event.logical.shared.ValueChangeHandler;
import com.vaadin.client.communication.RpcProxy;
import com.vaadin.client.communication.StateChangeEvent;
import com.vaadin.client.ui.AbstractComponentConnector;
import com.vaadin.shared.ui.Connect;

@Connect( DTable.class )
public class TableConnector
    extends AbstractComponentConnector
    implements ValueChangeHandler<Object[]>
{

    private static final long serialVersionUID = -5835057962150067653L;

    private DTableServerRpc serverRpc = null;

    public TableConnector()
    {
        serverRpc = RpcProxy.create( DTableServerRpc.class, this );
    }

    @Override
    public void init()
    {
        super.init();
        getWidget().addValueChangeHandler( this );
    }

    @Override
    public TableState getState()
    {
        return (TableState) super.getState();
    }

    @Override
    public VDTable getWidget()
    {
        return (VDTable) super.getWidget();
    }

    @Override
    public void onStateChanged( StateChangeEvent stateChangeEvent )
    {
        super.onStateChanged( stateChangeEvent );
        getWidget().setTableConfigData( getState().getTableConfigData() );
        getWidget().setTableExportData( getState().getTableExportData() );
        getWidget().setTranslationData( getState().getTranslationData() );
        getWidget().setTableData( getState().getTableData() );
        getWidget().processTableData();
    }

    @Override
    public void onValueChange( ValueChangeEvent<Object[]> event )
    {
        switch ( (Integer) event.getValue()[0] )
        {
            case TableEvents.NEW_REQUEST:
                serverRpc.newRequest( (String) event.getValue()[1] );
                break;
            case TableEvents.TABLE_BODY_CELL_CLICK:
                serverRpc.tableBodyCellClick( (Integer) event.getValue()[1], (Integer) event.getValue()[2],
                                              (Boolean) event.getValue()[3] );
                break;
            default:
                break;
        }
    }

}
