/**
 * Copyright (C) 2012-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtable.config;

import org.dussan.vaadin.dtable.config.tablesection.TableSectionConfig;
import org.dussan.vaadin.dtable.config.tablesection.alignments.ColumnAlign;
import org.dussan.vaadin.dtable.config.tablesection.alignments.RowAlign;

public class HeaderConfig
    extends TableSectionConfig
{

    private static final long serialVersionUID = -7622098280610656577L;

    private boolean allColumnsEnabled = false;

    private boolean expandedFrozenCellForActiveColumnEnabled = false;

    private boolean expandedCellForActiveColumnEnabled = false;

    private boolean tooltipEnabled = false;

    private boolean wordWrapInTooltipEnabled = false;

    private Integer tooltipMinimumWidth = 0;

    private Integer tooltipMaximumWidth = 0;

    private TooltipPosition tooltipPosition = null;

    public HeaderConfig()
    {
        setDefaultColumnAlignment( ColumnAlign.CENTER );
        setRowAlignment( RowAlign.MIDDLE );
        setTooltipPosition( TooltipPosition.BOTTOM );
    }

    public boolean isAllColumnsEnabled()
    {
        return allColumnsEnabled;
    }

    public void setAllColumnsEnabled( boolean allColumnsEnabled )
    {
        this.allColumnsEnabled = allColumnsEnabled;
    }

    public boolean isExpandedFrozenCellForActiveColumnEnabled()
    {
        return expandedFrozenCellForActiveColumnEnabled;
    }

    public void setExpandedFrozenCellForActiveColumnEnabled( boolean expandedFrozenCellForActiveColumnEnabled )
    {
        this.expandedFrozenCellForActiveColumnEnabled = expandedFrozenCellForActiveColumnEnabled;
    }

    public boolean isExpandedCellForActiveColumnEnabled()
    {
        return expandedCellForActiveColumnEnabled;
    }

    public void setExpandedCellForActiveColumnEnabled( boolean expandedCellForActiveColumnEnabled )
    {
        this.expandedCellForActiveColumnEnabled = expandedCellForActiveColumnEnabled;
    }

    public boolean isTooltipEnabled()
    {
        return tooltipEnabled;
    }

    public void setTooltipEnabled( boolean tooltipEnabled )
    {
        this.tooltipEnabled = tooltipEnabled;
    }

    public TooltipPosition getTooltipPosition()
    {
        return tooltipPosition;
    }

    public void setTooltipPosition( TooltipPosition tooltipPosition )
    {
        this.tooltipPosition = tooltipPosition;
    }

    public boolean isWordWrapInTooltipEnabled()
    {
        return wordWrapInTooltipEnabled;
    }

    public void setWordWrapInTooltipEnabled( boolean wordWrapInTooltipEnabled )
    {
        this.wordWrapInTooltipEnabled = wordWrapInTooltipEnabled;
    }

    public void setTooltipWidth( Integer tooltipMinimumWidth, Integer tooltipMaximumWidth )
    {
        setTooltipMinimumWidth( tooltipMinimumWidth );
        setTooltipMaximumWidth( tooltipMaximumWidth );
    }

    public Integer getTooltipMinimumWidth()
    {
        return tooltipMinimumWidth;
    }

    public void setTooltipMinimumWidth( Integer tooltipMinimumWidth )
    {
        this.tooltipMinimumWidth = tooltipMinimumWidth;
    }

    public Integer getTooltipMaximumWidth()
    {
        return tooltipMaximumWidth;
    }

    public void setTooltipMaximumWidth( Integer tooltipMaximumWidth )
    {
        this.tooltipMaximumWidth = tooltipMaximumWidth;
    }

    @Override
    public boolean isWordWrapEnabled()
    {
        // TODO enable for header
        return Boolean.FALSE;
    }

}
