/**
 * Copyright (C) 2012-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtable.windows.exporter.base;

import java.io.Serializable;

import org.dussan.vaadin.dtable.config.formatting.Formatting;
import org.dussan.vaadin.dtable.windows.exporter.type.ExportingColumnType;

public class ColumnDefinition
    implements Serializable
{

    private static final long serialVersionUID = -5591011315779145068L;

    private String header = null;

    private Integer scale = null;

    private Integer lengthOrPrecision = null;

    private Formatting formatting = null;

    private ExportingColumnType exportingColumnType = null;

    public ColumnDefinition( String header, Formatting formatting, ExportingColumnType exportingColumnType )
    {
        this.header = header;
        this.formatting = formatting;
        this.exportingColumnType = exportingColumnType;
    }

    public ColumnDefinition( String header, Formatting formatting, ExportingColumnType exportingColumnType,
                             Integer length )
    {
        this.header = header;
        this.formatting = formatting;
        this.exportingColumnType = exportingColumnType;
        this.lengthOrPrecision = length;
    }

    public ColumnDefinition( String header, Formatting formatting, ExportingColumnType exportingColumnType,
                             Integer precision, Integer scale )
    {
        this.header = header;
        this.formatting = formatting;
        this.exportingColumnType = exportingColumnType;
        this.lengthOrPrecision = precision;
        this.scale = scale;
    }

    public Integer getScale()
    {
        return scale;
    }

    public void setScale( Integer scale )
    {
        this.scale = scale;
    }

    public Integer getLength()
    {
        return lengthOrPrecision;
    }

    public void setLength( Integer length )
    {
        this.lengthOrPrecision = length;
    }

    public Integer getPrecision()
    {
        return lengthOrPrecision;
    }

    public void setPrecision( Integer precision )
    {
        this.lengthOrPrecision = precision;
    }

    public String getHeader()
    {
        return header;
    }

    public void setHeader( String header )
    {
        this.header = header;
    }

    public Formatting getFormatting()
    {
        return formatting;
    }

    public void setFormatting( Formatting formatting )
    {
        this.formatting = formatting;
    }

    public ExportingColumnType getExportingColumnType()
    {
        return exportingColumnType;
    }

    public void setExportingColumnType( ExportingColumnType exportingColumnType )
    {
        this.exportingColumnType = exportingColumnType;
    }

}
